==> haskell-adjunctions-4.4-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.4
id: adjunctions-4.4-7jaB6dHpNpxMNLr273bJr
key: adjunctions-4.4-7jaB6dHpNpxMNLr273bJr
license: BSD3
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors.
category: Data Structures, Adjunctions
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
abi: 9cb2457fc2d66bdd5d12e36253706f58
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/adjunctions-4.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/adjunctions-4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/adjunctions-4.4
hs-libraries: HSadjunctions-4.4-7jaB6dHpNpxMNLr273bJr
depends:
    array-0.5.2.0 base-4.10.1.0 comonad-5.0.3-1wQLfIXhDc15HcgpkWgfSP
    containers-0.5.10.2 contravariant-1.4.1-7cEYjzgkYgPFdXWpdMNGgr
    distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE
    free-4.12.4-BSemnwjGF3DBm1WyYoa7j1 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    profunctors-5.2.2-K8hTheEvEO12E0z5wuAp4A
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    semigroupoids-5.2.2-8ZtOWrOYrUnL0zPLyQ3GNy
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             comonad-5.0.3-1wQLfIXhDc15HcgpkWgfSP=0772d58444b5fab8850dd1c606485ec5
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             contravariant-1.4.1-7cEYjzgkYgPFdXWpdMNGgr=5e2c57f6d5adae18dd0e94f3a1c17f3b
             distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE=4194008627baa63a29bcee90329e8d22
             free-4.12.4-BSemnwjGF3DBm1WyYoa7j1=a267c64e2412992db1a011839853b735
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             profunctors-5.2.2-K8hTheEvEO12E0z5wuAp4A=908044a83daa6649d4a3896409f07b7b
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             semigroupoids-5.2.2-8ZtOWrOYrUnL0zPLyQ3GNy=e33df6e1251f1ffaa58802fd3ec22d0c
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
             void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC=a5672067c7a1184b41916f0fb2d0c330
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-adjunctions-4.4-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-adjunctions.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: adjunctions
version: 4.4
id: adjunctions-4.4-D9heo0rUUxpIDtFnouEX7G
key: adjunctions-4.4-D9heo0rUUxpIDtFnouEX7G
license: BSD3
copyright: Copyright (C) 2011-2014 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/adjunctions/
synopsis: Adjunctions and representable functors
description:
    Adjunctions and representable functors.
category: Data Structures, Adjunctions
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Control.Comonad.Representable.Store Control.Comonad.Trans.Adjoint
    Control.Monad.Representable.Reader
    Control.Monad.Representable.State Control.Monad.Trans.Adjoint
    Control.Monad.Trans.Contravariant.Adjoint Control.Monad.Trans.Conts
    Data.Functor.Adjunction Data.Functor.Contravariant.Adjunction
    Data.Functor.Contravariant.Rep Data.Functor.Rep
abi: e9445c42a775b5d94458d990c02b0f77
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/adjunctions-4.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/adjunctions-4.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/adjunctions-4.4
hs-libraries: HSadjunctions-4.4-D9heo0rUUxpIDtFnouEX7G
depends:
    array-0.5.2.0 base-4.10.1.0 comonad-5.0.3-1wQLfIXhDc15HcgpkWgfSP
    containers-0.5.10.2 contravariant-1.4.1-7cEYjzgkYgPFdXWpdMNGgr
    distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE
    free-4.12.4-85O5HJSOHaWFLaKEaVsQN3 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc
    profunctors-5.2.2-K8hTheEvEO12E0z5wuAp4A
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    semigroupoids-5.2.2-FDF6D6Ndk4K3Ji4q4rZOo
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC
abi-depends: array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             comonad-5.0.3-1wQLfIXhDc15HcgpkWgfSP=0772d58444b5fab8850dd1c606485ec5
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             contravariant-1.4.1-7cEYjzgkYgPFdXWpdMNGgr=5e2c57f6d5adae18dd0e94f3a1c17f3b
             distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE=4194008627baa63a29bcee90329e8d22
             free-4.12.4-85O5HJSOHaWFLaKEaVsQN3=6b492964c9cc13febe1a11ebcf0b66b4
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             profunctors-5.2.2-K8hTheEvEO12E0z5wuAp4A=908044a83daa6649d4a3896409f07b7b
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             semigroupoids-5.2.2-FDF6D6Ndk4K3Ji4q4rZOo=90fdd869255a98b23f946f5c8be29ab5
             semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=506de314acc216de1ce76634db1785eb
             void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC=a5672067c7a1184b41916f0fb2d0c330
haddock-interfaces: /usr/share/doc/haskell-adjunctions/html/adjunctions.haddock
haddock-html: /usr/share/doc/haskell-adjunctions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
